@@ -1,7 +1,7 @@
 // qtractorAudioPeak.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -259,8 +259,8 @@ bool qtractorAudioPeakThread::openPeakFile (void)
 		return false;
 	}
 
-	unsigned short iChannels   = m_pAudioFile->channels();
-	unsigned int   iSampleRate = m_pAudioFile->sampleRate();
+	const unsigned short iChannels = m_pAudioFile->channels();
+	const unsigned int iSampleRate = m_pAudioFile->sampleRate();
 
 	if (!m_pPeakFile->openWrite(iChannels, iSampleRate)) {
 		delete m_pAudioFile;
@@ -296,7 +296,7 @@ bool qtractorAudioPeakThread::writePeakFile (void)
 #endif
 
 	// Read another bunch of frames from the physical audio file...
-	int nread = m_pAudioFile->read(m_ppAudioFrames, c_iAudioFrames);
+	const int nread = m_pAudioFile->read(m_ppAudioFrames, c_iAudioFrames);
 	if (nread > 0)
 		m_pPeakFile->write(m_ppAudioFrames, nread);
 
@@ -316,7 +316,7 @@ void qtractorAudioPeakThread::closePeakFile (void)
 
 	// Get rid of physical used stuff.
 	if (m_ppAudioFrames) {
-		unsigned short iChannels = m_pAudioFile->channels();
+		const unsigned short iChannels = m_pAudioFile->channels();
 		for (unsigned short i = 0; i < iChannels; ++i)
 			delete [] m_ppAudioFrames[i];
 		delete [] m_ppAudioFrames;
@@ -384,20 +384,21 @@ qtractorAudioPeakFile::qtractorAudioPeakFile (
 
 	m_iRefCount    = 0;
 
-	// Set peak filename...
+	// Set (unique) peak filename...
 	QDir dir;
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession)
 		dir.setPath(pSession->sessionDir());
-	const QString sPeakFilePrefix
-		= QFileInfo(dir, QFileInfo(sFilename).fileName()).filePath()
-		+ '_' + QString::number(fTimeStretch);
-	QFileInfo peakInfo(sPeakFilePrefix + c_sPeakFileExt);
-	// Avoid duplicates, as much as psssible...
-	for (int i = 1; peakInfo.exists(); ++i) {
-		peakInfo.setFile(sPeakFilePrefix
-			+ '-' + QString::number(i) + c_sPeakFileExt);
-	}
+
+	const QFileInfo fileInfo(sFilename);
+	const QString& sPeakFilePrefix
+		= QFileInfo(dir, fileInfo.fileName()).filePath();
+	const QString& sPeakName
+		= qtractorAudioPeakFactory::peakName(sFilename, fTimeStretch);
+	const QFileInfo peakInfo(sPeakFilePrefix + '_'
+		+ QString::number(qHash(sPeakName), 16)
+		+ c_sPeakFileExt);
+
 	m_peakFile.setFileName(peakInfo.absoluteFilePath());
 }
 
@@ -406,24 +407,20 @@ qtractorAudioPeakFile::qtractorAudioPeakFile (
 qtractorAudioPeakFile::~qtractorAudioPeakFile (void)
 {
 	// Check if it's aborting (ought to be atomic)...
-	bool bAborted = m_bWaitSync;
+	const bool bAborted = m_bWaitSync;
 	m_bWaitSync = false;
 
 	// Close the file, anyway now.
 	closeWrite();
 	closeRead();
 
-	// Tell master-factory that we're out.
+	// Tell master-factory that we're out immediately (if aborted)...
 	qtractorSession *pSession = qtractorSession::getInstance();
 	if (pSession) {
 		qtractorAudioPeakFactory *pPeakFactory
 			= pSession->audioPeakFactory();
-		if (pPeakFactory) {
-			pPeakFactory->removePeak(this);
-			// Do we get rid from the filesystem too?
-			if (pPeakFactory->isAutoRemove() || bAborted)
-				m_peakFile.remove();
-		}
+		if (pPeakFactory)
+			pPeakFactory->removePeak(this, bAborted);
 	}
 }
 
@@ -523,6 +520,12 @@ float qtractorAudioPeakFile::timeStretch (void) const
 }
 
 
+QString qtractorAudioPeakFile::peakName (void) const
+{
+	return qtractorAudioPeakFactory::peakName(m_sFilename, m_fTimeStretch);
+}
+
+
 // Peak cache properties accessors.
 QString qtractorAudioPeakFile::name (void) const
 {
@@ -557,7 +560,7 @@ qtractorAudioPeakFile::Frame *qtractorAudioPeakFile::read (
 #endif
 
 	// Cache effect, only valid if we're really reading...
-	unsigned long iPeakEnd = iPeakOffset + iPeakFrames;
+	const unsigned long iPeakEnd = iPeakOffset + iPeakFrames;
 	if (iPeakOffset >= m_iBuffOffset && m_iBuffOffset < iPeakEnd) {
 		unsigned long iBuffEnd = m_iBuffOffset + m_iBuffLength;
 		if (iBuffEnd >= iPeakEnd)
@@ -603,8 +606,10 @@ unsigned int qtractorAudioPeakFile::readBuffer (
 
 	// Grab new contents from peak file...
 	char *pBuffer = (char *) (m_pBuffer + m_peakHeader.channels * iBuffOffset);
-	unsigned long iOffset = iPeakOffset * m_peakHeader.channels * sizeof(Frame);
-	unsigned int  iLength = iPeakFrames * m_peakHeader.channels * sizeof(Frame);
+	const unsigned long iOffset
+		= iPeakOffset * m_peakHeader.channels * sizeof(Frame);
+	const unsigned int iLength
+		= iPeakFrames * m_peakHeader.channels * sizeof(Frame);
 
 	int nread = 0;
 	if (m_peakFile.seek(sizeof(Header) + iOffset))
@@ -735,7 +740,7 @@ void qtractorAudioPeakFile::write (
 	for (unsigned int n = 0; n < iAudioFrames; ++n) {
 		// Accumulate for this sample frame...
 		for (unsigned short i = 0; i < m_peakHeader.channels; ++i) {
-			float fSample = ppAudioFrames[i][n];
+			const float fSample = ppAudioFrames[i][n];
 			if (m_peakMax[i] < fSample)
 				m_peakMax[i] = fSample;
 			if (m_peakMin[i] > fSample)
@@ -787,6 +792,13 @@ void qtractorAudioPeakFile::removeRef (void)
 }
 
 
+// Physical removal.
+void qtractorAudioPeakFile::remove (void)
+{
+	m_peakFile.remove();
+}
+
+
 // Sync thread state flags accessors.
 void qtractorAudioPeakFile::setWaitSync ( bool bWaitSync )
 {
@@ -829,6 +841,13 @@ qtractorAudioPeakFactory::~qtractorAudioPeakFactory (void)
 
 
 // The peak file factory-methods.
+QString qtractorAudioPeakFactory::peakName (
+	const QString& sFilename, float fTimeStretch )
+{
+	return sFilename + '_' + QString::number(fTimeStretch);
+}
+
+
 qtractorAudioPeak* qtractorAudioPeakFactory::createPeak (
 	const QString& sFilename, float fTimeStretch )
 {
@@ -839,22 +858,29 @@ qtractorAudioPeak* qtractorAudioPeakFactory::createPeak (
 		m_pPeakThread->start();
 	}
 
-	const QString sKey = sFilename + '_' + QString::number(fTimeStretch);
-	qtractorAudioPeakFile *pPeakFile = m_peaks.value(sKey, NULL);
+	const QString& sPeakName = peakName(sFilename, fTimeStretch);
+	qtractorAudioPeakFile *pPeakFile = m_peaks.value(sPeakName);
 	if (pPeakFile == NULL) {
 		pPeakFile = new qtractorAudioPeakFile(sFilename, fTimeStretch);
-		m_peaks.insert(sKey, pPeakFile);
+		m_peaks.insert(sPeakName, pPeakFile);
 	}
 
 	return new qtractorAudioPeak(pPeakFile);
 }
 
-void qtractorAudioPeakFactory::removePeak ( qtractorAudioPeakFile *pPeakFile )
+
+void qtractorAudioPeakFactory::removePeak (
+	qtractorAudioPeakFile *pPeakFile, bool bAborted )
 {
 	QMutexLocker locker(&m_mutex);
 
-	m_peaks.remove(pPeakFile->filename()
-		+ '_' + QString::number(pPeakFile->timeStretch()));
+	m_peaks.remove(pPeakFile->peakName());
+
+	if (bAborted)
+		pPeakFile->remove();
+	else
+	if (m_bAutoRemove)
+		m_files.append(pPeakFile->name());
 }
 
 
@@ -884,4 +910,14 @@ void qtractorAudioPeakFactory::sync ( qtractorAudioPeakFile *pPeakFile )
 }
 
 
+// Cleanup method.
+void qtractorAudioPeakFactory::cleanup (void)
+{
+	QStringListIterator iter(m_files);
+	while (iter.hasNext())
+		QFile::remove(iter.next());
+	m_files.clear();
+}
+
+
 // end of qtractorAudioPeak.cpp
