@@ -1,7 +1,7 @@
 // qtractorClipForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -651,9 +651,13 @@ void qtractorClipForm::browseFilename (void)
 	QString sFilename;
 
 	const QString& sTitle = tr("%1 Clip File").arg(sType) + " - " QTRACTOR_TITLE;
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
+	QFileDialog::Options options = 0;
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sFilename = QFileDialog::getOpenFileName(this,
-		sTitle, m_ui.FilenameComboBox->currentText(), sFilter);
+		sTitle, m_ui.FilenameComboBox->currentText(), sFilter, NULL, options);
 #else
 	QFileDialog fileDialog(this,
 		sTitle, m_ui.FilenameComboBox->currentText(), sFilter);
@@ -678,6 +682,8 @@ void qtractorClipForm::browseFilename (void)
 			break;
 		}
 		fileDialog.setSidebarUrls(urls);
+		if (pOptions->bDontUseNativeDialogs)
+			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
 	// Show dialog...
 	if (fileDialog.exec())
