@@ -1,7 +1,7 @@
 // qtractorInsertPlugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2011, Holger Dehnhardt.
 
    This program is free software; you can redistribute it and/or
@@ -162,7 +162,7 @@ bool qtractorInsertPluginType::open (void)
 	m_sLabel = m_sName;
 
 	// Pseudo-plugin unique identifier.
-	m_iUniqueID = iChannels;
+	m_iUniqueID = qHash(m_sLabel) ^ qHash(iChannels);
 
 	// Pseudo-plugin port counts...
 	m_iControlIns  = 2;
@@ -199,6 +199,21 @@ qtractorInsertPluginType *qtractorInsertPluginType::createType (
 }
 
 
+// Instance cached-deferred accesors.
+const QString& qtractorInsertPluginType::aboutText (void)
+{
+	if (m_sAboutText.isEmpty()) {
+		m_sAboutText += QObject::tr("Insert Send/Return pseudo-plugin.");
+		m_sAboutText += '\n';
+		m_sAboutText += QTRACTOR_WEBSITE;
+		m_sAboutText += '\n';
+		m_sAboutText += QTRACTOR_COPYRIGHT;
+	}
+
+	return m_sAboutText;
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorInsertPlugin -- Insert pseudo-plugin instance.
 //
@@ -504,7 +519,7 @@ bool qtractorAuxSendPluginType::open (void)
 	m_sLabel.remove(' ');
 
 	// Pseudo-plugin unique identifier.
-	m_iUniqueID = iChannels;
+	m_iUniqueID = qHash(m_sLabel) ^ qHash(iChannels);
 
 	// Pseudo-plugin port counts...
 	m_iControlIns  = 1;
@@ -541,6 +556,21 @@ qtractorAuxSendPluginType *qtractorAuxSendPluginType::createType (
 }
 
 
+// Instance cached-deferred accesors.
+const QString& qtractorAuxSendPluginType::aboutText (void)
+{
+	if (m_sAboutText.isEmpty()) {
+		m_sAboutText += QObject::tr("Aux Send pseudo-plugin.");
+		m_sAboutText += '\n';
+		m_sAboutText += QTRACTOR_WEBSITE;
+		m_sAboutText += '\n';
+		m_sAboutText += QTRACTOR_COPYRIGHT;
+	}
+
+	return m_sAboutText;
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorAuxSendPlugin -- Aux-send pseudo-plugin instance.
 //
