@@ -1,7 +1,7 @@
 // qtractorLv2Plugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -658,7 +658,7 @@ static QString qtractor_lv2_state_prefix ( qtractorLv2Plugin *pLv2Plugin )
 	sPrefix += '-';
 
 	if (sPresetName.isEmpty()) {
-		sPrefix += QString::number(pLv2Plugin->type()->uniqueID(), 16);
+		sPrefix += QString::number(pLv2Plugin->uniqueID(), 16);
 	} else {
 		sPrefix += qtractorSession::sanitize(sPresetName);
 	}
@@ -947,7 +947,7 @@ static void qtractor_lv2_set_port_value ( const char *port_symbol,
 		= lilv_plugin_get_port_by_symbol(plugin, symbol);
 	if (port) {
 		const float val = *(float *) value;
-		unsigned long port_index = lilv_port_get_index(plugin, port);
+		const unsigned long port_index = lilv_port_get_index(plugin, port);
 		pLv2Plugin->updateParamValue(port_index, val, true);
 	}
 
@@ -1323,10 +1323,13 @@ void qtractorLv2PluginType::lv2_open (void)
 
 	g_lv2_world = lilv_world_new();
 
-	// Set dyn-manifest support option...
-	LilvNode *dyn_manifest = lilv_new_bool(g_lv2_world, true);
-	lilv_world_set_option(g_lv2_world, LILV_OPTION_DYN_MANIFEST, dyn_manifest);
-	lilv_node_free(dyn_manifest);
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bLv2DynManifest) {
+		// Set dyn-manifest support option...
+		LilvNode *dyn_manifest = lilv_new_bool(g_lv2_world, true);
+		lilv_world_set_option(g_lv2_world, LILV_OPTION_DYN_MANIFEST, dyn_manifest);
+		lilv_node_free(dyn_manifest);
+	}
 
 	// Find all installed plugins.
 	lilv_world_load_all(g_lv2_world);
@@ -1577,6 +1580,48 @@ bool qtractorLv2PluginType::getTypes ( qtractorPluginPath& path )
 }
 
 
+// Instance cached-deferred accesors.
+const QString& qtractorLv2PluginType::aboutText (void)
+{
+	if (m_sAboutText.isEmpty() && m_lv2_plugin) {
+		LilvNode *node = lilv_plugin_get_project(m_lv2_plugin);
+		if (node) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+			m_sAboutText += QObject::tr("Project: ");
+			m_sAboutText += lilv_node_as_string(node);
+			lilv_node_free(node);
+		}
+		node = lilv_plugin_get_author_name(m_lv2_plugin);
+		if (node) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+			m_sAboutText += QObject::tr("Author: ");
+			m_sAboutText += lilv_node_as_string(node);
+			lilv_node_free(node);
+		}
+		node = lilv_plugin_get_author_email(m_lv2_plugin);
+		if (node) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+		//	m_sAboutText += QObject::tr("Email: ");
+			m_sAboutText += lilv_node_as_string(node);
+			lilv_node_free(node);
+		}
+		node = lilv_plugin_get_author_homepage(m_lv2_plugin);
+		if (node) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+		//	m_sAboutText += QObject::tr("Homepage: ");
+			m_sAboutText += lilv_node_as_string(node);
+			lilv_node_free(node);
+		}
+	}
+
+	return m_sAboutText;
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorLv2Plugin -- LV2 plugin instance.
 //
@@ -1917,11 +1962,11 @@ qtractorLv2Plugin::qtractorLv2Plugin ( qtractorPluginList *pList,
 				const LilvPort *port = lilv_plugin_get_port_by_designation(
 					plugin, g_lv2_input_class, member.node);
 				if (port) {
-					unsigned long index = lilv_port_get_index(plugin, port);
+					const unsigned long iIndex = lilv_port_get_index(plugin, port);
 					qtractorLv2PluginParam *pParam
-						= static_cast<qtractorLv2PluginParam *> (findParam(index));
+						= static_cast<qtractorLv2PluginParam *> (findParam(iIndex));
 					if (pParam) {
-						m_lv2_time_ports.insert(index, i);
+						m_lv2_time_ports.insert(iIndex, i);
 						member.params->append(pParam);
 					}
 				}
@@ -2499,7 +2544,7 @@ void qtractorLv2Plugin::openEditor ( QWidget */*pParent*/ )
 		const qtractorPlugin::Params::ConstIterator& param_end = params.constEnd();
 		for ( ; param != param_end; ++param) {
 			qtractorPluginParam *pParam = param.value();
-			float fValue = pParam->value();
+			const float fValue = pParam->value();
 			suil_instance_port_event(m_suil_instance,
 				pParam->index(), sizeof(float), 0, &fValue);
 		}
@@ -2781,7 +2826,7 @@ void qtractorLv2Plugin::lv2_ui_write ( uint32_t port_index,
 #ifdef CONFIG_LV2_ATOM
 	if (protocol == g_lv2_atom_event_type) {
 		char buf[sizeof(ControlEvent) + buffer_size];
-		ControlEvent* ev = (ControlEvent *) buf;
+		ControlEvent *ev = (ControlEvent *) buf;
 		ev->index    = port_index;
 		ev->protocol = protocol;
 		ev->size     = buffer_size;
@@ -2845,6 +2890,7 @@ void qtractorLv2Plugin::freezeConfigs (void)
 #endif	// CONFIG_LV2_STATE
 }
 
+
 // Plugin configuration/state (load) realization.
 void qtractorLv2Plugin::realizeConfigs (void)
 {
