@@ -1,7 +1,7 @@
 // qtractorLv2Plugin.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -148,9 +148,12 @@ public:
 	unsigned short midiAtomOuts()  const { return m_iMidiAtomOuts;  }
 #endif
 
+	// Instance cached-deferred accesors.
+	const QString& aboutText();
+
 protected:
 
-	// LV2 plgin URI.
+	// LV2 plugin URI.
 	QString    m_sUri;
 
 	// LV2 descriptor itself.
