@@ -1,7 +1,7 @@
 // qtractorMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -270,8 +270,8 @@ public slots:
 
 	void stabilizeForm();
 
-	void addAudioFile(const QString& sFilename, bool bAutoRemove = false);
-	void addMidiFile(const QString& sFilename, bool bAutoRemove = false);
+	void addAudioFile(const QString& sFilename);
+	void addMidiFile(const QString& sFilename);
 
 	void selectionNotifySlot(qtractorMidiEditor *pMidiEditor);
 	void changeNotifySlot(qtractorMidiEditor *pMidiEditor);
@@ -397,6 +397,7 @@ protected:
 	void updateMidiControl();
 	void updateAudioMetronome();
 	void updateMidiMetronome();
+	void updateSyncViewHold();
 
 	void updateContents(qtractorMidiEditor *pMidiEditor, bool bRefresh);
 	void updateDirtyCount(bool bDirtyCount);
