@@ -374,62 +374,4 @@ bool qtractorMidiEditCommand::undo (void)
 }
 
 
-//----------------------------------------------------------------------
-// class qtractorMidiClipCommand - declaration.
-//
-
-// Constructor.
-qtractorMidiClipCommand::qtractorMidiClipCommand ( const QString& sName )
-	: qtractorCommand(sName)
-{
-}
-
-
-// Destructor.
-qtractorMidiClipCommand::~qtractorMidiClipCommand (void)
-{
-	qDeleteAll(m_editCommands);
-	m_editCommands.clear();
-}
-
-
-// Composite command methods.
-void qtractorMidiClipCommand::addEditCommand ( qtractorMidiEditCommand *pEditCommand )
-{
-	m_editCommands.append(pEditCommand);
-}
-
-
-// Composite predicate.
-bool qtractorMidiClipCommand::isEmpty (void) const
-{
-	return m_editCommands.isEmpty();
-}
-
-
-// Virtual command methods.
-bool qtractorMidiClipCommand::redo (void)
-{
-	QListIterator<qtractorMidiEditCommand *> iter(m_editCommands);
-	while (iter.hasNext()) {
-	    if (!iter.next()->redo())
-			return false;
-	}
-
-	return true;
-}
-
-bool qtractorMidiClipCommand::undo (void)
-{
-	QListIterator<qtractorMidiEditCommand *> iter(m_editCommands);
-	iter.toBack();
-	while (iter.hasPrevious()) {
-	    if (!iter.previous()->undo())
-			return false;
-	}
-
-	return true;
-}
-
-
 // end of qtractorMidiEditCommand.cpp
