@@ -1,7 +1,7 @@
 // qtractorMidiEditor.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -321,6 +321,12 @@ public:
 	QString eventToolTip(qtractorMidiEvent *pEvent,
 		long iTimeDelta = 0, int iNoteDelta = 0, int iValueDelta = 0) const;
 
+	// Temporary sync-view/follow-playhead hold state.
+	void setSyncViewHoldOn(bool bOn);
+
+	void setSyncViewHold(bool bSyncViewHold);
+	bool isSyncViewHold() const;
+
 	// Visualize the event selection drag-move.
 	void paintDragState(qtractorScrollView *pScrollView,
 		QPainter *pPainter);
@@ -673,6 +679,10 @@ private:
 	// Snap-to-scale (aka.in-place scale-quantize) stuff.
 	int m_iSnapToScaleKey;
 	int m_iSnapToScaleType;
+
+	// Temporary sync-view/follow-playhead hold state.
+	bool m_bSyncViewHold;
+	int  m_iSyncViewHold;
 };
 
 
