@@ -1,7 +1,7 @@
 // qtractorMidiEditorForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -116,6 +116,7 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 
 	// View/Snap-to-beat actions initialization...
 	int iSnap = 0;
+	const QIcon snapIcon(":/images/itemBeat.png");
 	const QString sSnapObjectName("viewSnapPerBeat%1");
 	const QString sSnapStatusTip(tr("Set current snap to %1"));
 	const QStringList& snapItems = qtractorTimeScale::snapItems();
@@ -126,6 +127,7 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 		pAction->setObjectName(sSnapObjectName.arg(iSnap));
 		pAction->setStatusTip(sSnapStatusTip.arg(sSnapText));
 		pAction->setCheckable(true);
+	//	pAction->setIcon(snapIcon);
 		pAction->setData(iSnap++);
 		QObject::connect(pAction,
 			SIGNAL(triggered(bool)),
@@ -135,7 +137,14 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 	}
 
 	// Pre-fill the combo-boxes...
-	m_pSnapPerBeatComboBox->insertItems(0, snapItems);
+	m_pSnapPerBeatComboBox->setIconSize(QSize(8, 16));
+	snapIter.toFront();
+	if (snapIter.hasNext())
+		m_pSnapPerBeatComboBox->addItem(
+			QIcon(":/images/itemNone.png"), snapIter.next());
+	while (snapIter.hasNext())
+		m_pSnapPerBeatComboBox->addItem(snapIcon, snapIter.next());
+//	m_pSnapPerBeatComboBox->insertItems(0, snapItems);
 
 	const QIcon icon(":/images/itemProperty.png");
 
@@ -520,6 +529,8 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 		m_pMidiEditor->setSyncView(pOptions->bMidiFollow);
 		m_pMidiEditor->setSnapToScaleKey(pOptions->iMidiSnapToScaleKey);
 		m_pMidiEditor->setSnapToScaleType(pOptions->iMidiSnapToScaleType);
+		// Initial transport display options...
+		m_pMidiEditor->setSyncViewHold(pOptions->bSyncViewHold);
 		// Default snap-per-beat setting...
 		m_pSnapPerBeatComboBox->setCurrentIndex(pOptions->iMidiSnapPerBeat);
 		// Default snap-to-scale settings...
@@ -814,8 +825,8 @@ void qtractorMidiEditorForm::setup ( qtractorMidiClip *pMidiClip )
 
 	// Get those time-scales in sync,
 	// while keeping zoom ratios persistant...
-	unsigned short iHorizontalZoom = m_pMidiEditor->horizontalZoom();
-	unsigned short iVerticalZoom   = m_pMidiEditor->verticalZoom();
+	const unsigned short iHorizontalZoom = m_pMidiEditor->horizontalZoom();
+	const unsigned short iVerticalZoom = m_pMidiEditor->verticalZoom();
 	qtractorTimeScale *pTimeScale  = m_pMidiEditor->timeScale();
 	pTimeScale->copy(*pSession->timeScale());
 	m_pMidiEditor->setHorizontalZoom(iHorizontalZoom);
@@ -857,15 +868,15 @@ void qtractorMidiEditorForm::setup ( qtractorMidiClip *pMidiClip )
 	// (Re)try to position the editor in same of track view...
 	qtractorTracks *pTracks = pMainForm->tracks();
 	if (pTracks) {
-		unsigned long iFrame = pTimeScale->frameFromPixel(
+		unsigned long iFrame = pSession->frameFromPixel(
 			(pTracks->trackView())->contentsX());
 		if (iFrame  > m_pMidiEditor->offset()) {
 			iFrame -= m_pMidiEditor->offset();
 		} else {
 			iFrame = 0;
 		}
-		int cx = pTimeScale->pixelFromFrame(iFrame);
-		int cy = (m_pMidiEditor->editView())->contentsY();
+		const int cx = pTimeScale->pixelFromFrame(iFrame);
+		const int cy = (m_pMidiEditor->editView())->contentsY();
 		(m_pMidiEditor->editView())->setContentsPos(cx, cy);
 	}
 
@@ -921,10 +932,14 @@ bool qtractorMidiEditorForm::saveClipFile ( bool bPrompt )
 		const QString sExt("mid");
 		const QString& sTitle  = tr("Save MIDI Clip") + " - " QTRACTOR_TITLE;
 		const QString& sFilter = tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt);
-	#if 0//QT_VERSION < 0x040400
+	#if 1//QT_VERSION < 0x040400
 		// Ask for the filenames to open...
+		QFileDialog::Options options = 0;
+		qtractorOptions *pOptions = qtractorOptions::getInstance();
+		if (pOptions && pOptions->bDontUseNativeDialogs)
+			options |= QFileDialog::DontUseNativeDialog;
 		sFilename = QFileDialog::getSaveFileName(this,
-			sTitle, sFilename, sFilter);
+			sTitle, sFilename, sFilter, NULL, options);
 	#else
 		// Construct open-files dialog...
 		QFileDialog fileDialog(this,
@@ -940,6 +955,8 @@ bool qtractorMidiEditorForm::saveClipFile ( bool bPrompt )
 			urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 			urls.append(QUrl::fromLocalFile(pOptions->sMidiDir));
 			fileDialog.setSidebarUrls(urls);
+			if (pOptions->bDontUseNativeDialogs)
+				fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 		}
 		// Show dialog...
 		if (fileDialog.exec())
@@ -1764,7 +1781,7 @@ void qtractorMidiEditorForm::updatePlayHead ( unsigned long iPlayHead )
 // Zoom view menu stabilizer.
 void qtractorMidiEditorForm::updateZoomMenu (void)
 {
-	int iZoomMode = m_pMidiEditor->zoomMode();
+	const int iZoomMode = m_pMidiEditor->zoomMode();
 	
 	m_ui.viewZoomHorizontalAction->setChecked(
 		iZoomMode == qtractorMidiEditor::ZoomHorizontal);
@@ -1784,7 +1801,7 @@ void qtractorMidiEditorForm::updateSnapMenu (void)
 	if (pTimeScale == NULL)
 		return;
 
-	int iSnapCurrent
+	const int iSnapCurrent
 		= qtractorTimeScale::indexFromSnap(pTimeScale->snapPerBeat());
 
 	int iSnap = 0;
@@ -1807,7 +1824,7 @@ void qtractorMidiEditorForm::updateScaleMenu (void)
 {
 	m_ui.viewScaleMenu->clear();
 
-	int iSnapToScaleKey = m_pMidiEditor->snapToScaleKey();
+	const int iSnapToScaleKey = m_pMidiEditor->snapToScaleKey();
 	int iScaleKey = 0;
 	QStringListIterator iter_key(qtractorMidiEditor::scaleKeyNames());
 	while (iter_key.hasNext()) {
@@ -1820,7 +1837,7 @@ void qtractorMidiEditorForm::updateScaleMenu (void)
 
 	m_ui.viewScaleMenu->addSeparator();
 
-	int iSnapToScaleType = m_pMidiEditor->snapToScaleType();
+	const int iSnapToScaleType = m_pMidiEditor->snapToScaleType();
 	int iScaleType = 0;
 	QStringListIterator iter_type(qtractorMidiEditor::scaleTypeNames());
 	while (iter_type.hasNext()) {
@@ -1841,7 +1858,7 @@ void qtractorMidiEditorForm::snapPerBeatChanged ( int iSnap )
 		return;
 
 	// Avoid bogus changes...
-	unsigned short iSnapPerBeat = qtractorTimeScale::snapFromIndex(iSnap);
+	const unsigned short iSnapPerBeat = qtractorTimeScale::snapFromIndex(iSnap);
 	if (iSnapPerBeat == pTimeScale->snapPerBeat())
 		return;
 
