@@ -316,6 +316,12 @@ QString qtractorMidiEventListModel::itemDisplay (
 				return tr("Key Press (%1)").arg(pEvent->note());
 			case qtractorMidiEvent::CONTROLLER:
 				return tr("Controller (%1)").arg(pEvent->controller());
+			case qtractorMidiEvent::CONTROL14:
+				return tr("Control 14 (%1)").arg(pEvent->controller());
+			case qtractorMidiEvent::REGPARAM:
+				return tr("RPN (%1)").arg(pEvent->param());
+			case qtractorMidiEvent::NONREGPARAM:
+				return tr("NRPN (%1)").arg(pEvent->param());
 			case qtractorMidiEvent::PGMCHANGE:
 				return tr("Pgm Change");
 			case qtractorMidiEvent::CHANPRESS:
@@ -338,6 +344,12 @@ QString qtractorMidiEventListModel::itemDisplay (
 				return m_pEditor->noteName(pEvent->note());
 			case qtractorMidiEvent::CONTROLLER:
 				return m_pEditor->controllerName(pEvent->controller());
+			case qtractorMidiEvent::REGPARAM:
+				return m_pEditor->rpnNames().value(pEvent->param());
+			case qtractorMidiEvent::NONREGPARAM:
+				return m_pEditor->nrpnNames().value(pEvent->param());
+			case qtractorMidiEvent::CONTROL14:
+				return m_pEditor->control14Name(pEvent->controller());
 			default:
 				break;
 			}
@@ -349,6 +361,9 @@ QString qtractorMidiEventListModel::itemDisplay (
 			case qtractorMidiEvent::KEYPRESS:
 				return QString::number(pEvent->velocity());
 			case qtractorMidiEvent::CONTROLLER:
+			case qtractorMidiEvent::REGPARAM:
+			case qtractorMidiEvent::NONREGPARAM:
+			case qtractorMidiEvent::CONTROL14:
 			case qtractorMidiEvent::PGMCHANGE:
 			case qtractorMidiEvent::CHANPRESS:
 				return QString::number(pEvent->value());
@@ -531,9 +546,17 @@ QWidget *qtractorMidiEventItemDelegate::createEditor ( QWidget *pParent,
 	case 3: // Value.
 	{
 		QSpinBox *pSpinBox = new QSpinBox(pParent);
-		if (pEvent->type() == qtractorMidiEvent::PITCHBEND) {
+		const qtractorMidiEvent::EventType etype = pEvent->type();
+		if (etype == qtractorMidiEvent::PITCHBEND) {
 			pSpinBox->setMinimum(-8192);
 			pSpinBox->setMaximum(+8192);
+		}
+		else
+		if (etype == qtractorMidiEvent::REGPARAM    ||
+			etype == qtractorMidiEvent::NONREGPARAM ||
+			etype == qtractorMidiEvent::CONTROL14) {
+			pSpinBox->setMinimum(0);
+			pSpinBox->setMaximum(16383);
 		} else {
 			pSpinBox->setMinimum(0);
 			pSpinBox->setMaximum(127);
@@ -678,7 +701,7 @@ void qtractorMidiEventItemDelegate::setModelData ( QWidget *pEditor,
 		if (pTimeSpinBox) {
 			unsigned long iTime
 				= pTimeScale->tickFromFrame(pTimeSpinBox->valueFromText());
-			if (iTime > pMidiEditor->timeOffset())
+			if (iTime  > pMidiEditor->timeOffset())
 				iTime -= pMidiEditor->timeOffset();
 			else
 				iTime = 0;
