@@ -1,7 +1,7 @@
 // qtractorOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -227,6 +227,8 @@ void qtractorOptions::loadOptions (void)
 	bAudioOutputAutoConnect = m_settings.value("/AudioOutputAutoConnect", true).toBool();
 	bOpenEditor = m_settings.value("/OpenEditor", true).toBool();
 	bDummyVstScan = m_settings.value("/DummyVstScan", true).toBool();
+	bLv2DynManifest = m_settings.value("/Lv2DynManifest", false).toBool();
+	bSaveCurve14bit = m_settings.value("/SaveCurve14bit", false).toBool();
 	m_settings.endGroup();
 
 	// Instrument file list.
@@ -309,13 +311,29 @@ void qtractorOptions::loadOptions (void)
 	iMidiSnapToScaleType = m_settings.value("/SnapToScaleType", 0).toInt();
 	m_settings.endGroup();
 
+	m_settings.endGroup(); // MidiEditor
+
+	// User preference options.
+	m_settings.beginGroup("/Preferences");
+
 	// Meter colors.
 	m_settings.beginGroup("/Colors");
 	audioMeterColors = m_settings.value("/AudioMeter").toStringList();
 	midiMeterColors  = m_settings.value("/MidiMeter").toStringList();
 	m_settings.endGroup();
 
+	// Transport view options.
+	m_settings.beginGroup("/Transport");
+	bSyncViewHold = m_settings.value("/SyncViewHold", false).toBool();
 	m_settings.endGroup();
+
+	// Run-time special semi/non-persistent options.
+	m_settings.beginGroup("/Dialogs");
+	bUseNativeDialogs = m_settings.value("/UseNativeDialogs", true).toBool();
+	bDontUseNativeDialogs = !bUseNativeDialogs;
+	m_settings.endGroup();
+
+	m_settings.endGroup(); // Preferences
 }
 
 
@@ -375,7 +393,7 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/TransportMode", iTransportMode);
 	m_settings.endGroup();
 
-	// Audio redndering options group.
+	// Audio rendering options group.
 	m_settings.beginGroup("/Audio");
 	m_settings.setValue("/CaptureExt", sAudioCaptureExt);
 	m_settings.setValue("/CaptureType", iAudioCaptureType);
@@ -412,9 +430,9 @@ void qtractorOptions::saveOptions (void)
 	m_settings.beginGroup("/Metronome");
 	// Audio metronome...
 	m_settings.setValue("/BarFilename", sMetroBarFilename);
-	m_settings.setValue("/BarGain", fMetroBarGain);
+	m_settings.setValue("/BarGain", double(fMetroBarGain));
 	m_settings.setValue("/BeatFilename", sMetroBeatFilename);
-	m_settings.setValue("/BeatGain", fMetroBeatGain);
+	m_settings.setValue("/BeatGain", double(fMetroBeatGain));
 	// MIDI metronome...
 	m_settings.setValue("/Channel", iMetroChannel);
 	m_settings.setValue("/BarNote", iMetroBarNote);
@@ -453,7 +471,7 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/PluginType", iPluginType);
 	m_settings.setValue("/PluginActivate", bPluginActivate);
 	m_settings.setValue("/CurveMode", iCurveMode);
-    m_settings.setValue("/EditRangeOptions", iEditRangeOptions);
+	m_settings.setValue("/EditRangeOptions", iEditRangeOptions);
 	m_settings.setValue("/MidButtonModifier", bMidButtonModifier);
 	m_settings.endGroup();
 
@@ -476,6 +494,8 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/AudioOutputAutoConnect", bAudioOutputAutoConnect);
 	m_settings.setValue("/OpenEditor", bOpenEditor);
 	m_settings.setValue("/DummyVstScan", bDummyVstScan);
+	m_settings.setValue("/Lv2DynManifest", bLv2DynManifest);
+	m_settings.setValue("/SaveCurve14bit", bSaveCurve14bit);
 	m_settings.endGroup();
 
 	// Instrument file list.
@@ -494,18 +514,18 @@ void qtractorOptions::saveOptions (void)
 	iFile = 0;
 	m_settings.beginGroup("/MidiControlFiles");
 	QStringListIterator iter2(midiControlFiles);
-    while (iter2.hasNext())
+	while (iter2.hasNext())
 		m_settings.setValue(sFilePrefix.arg(++iFile), iter2.next());
-    // Cleanup old entries, if any...
-    while (!m_settings.value(sFilePrefix.arg(++iFile)).isNull())
-        m_settings.remove(sFilePrefix.arg(iFile));
+	// Cleanup old entries, if any...
+	while (!m_settings.value(sFilePrefix.arg(++iFile)).isNull())
+		m_settings.remove(sFilePrefix.arg(iFile));
 	m_settings.endGroup();
 
 	// Recent file list.
 	iFile = 0;
 	m_settings.beginGroup("/RecentFiles");
 	QStringListIterator iter3(recentFiles);
-    while (iter3.hasNext())
+	while (iter3.hasNext())
 		m_settings.setValue(sFilePrefix.arg(++iFile), iter3.next());
 	m_settings.endGroup();
 
@@ -549,14 +569,29 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/SnapToScaleType", iMidiSnapToScaleType);
 	m_settings.endGroup();
 
+	m_settings.endGroup(); // MidiEditor
+
+	// User preference options.
+	m_settings.beginGroup("/Preferences");
+
 	// Meter colors.
 	m_settings.beginGroup("/Colors");
 	m_settings.setValue("/AudioMeter", audioMeterColors);
 	m_settings.setValue("/MidiMeter", midiMeterColors);
 	m_settings.endGroup();
 
+	// Transport view options.
+	m_settings.beginGroup("/Transport");
+	m_settings.setValue("/SyncViewHold", bSyncViewHold);
 	m_settings.endGroup();
 
+	// Run-time special semi/non-persistent options.
+	m_settings.beginGroup("/Dialogs");
+	m_settings.setValue("/UseNativeDialogs", bUseNativeDialogs);
+	m_settings.endGroup();
+
+	m_settings.endGroup(); // Preferences
+
 	// Save/commit to disk.
 	m_settings.sync();
 }
