@@ -1,7 +1,7 @@
 // qtractorOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -207,6 +207,12 @@ public:
 	// VST dummy plugin scan option.
 	bool bDummyVstScan;
 
+	// LV2 plugin specific options.
+	bool bLv2DynManifest;
+
+	// Automation preferred resolution (14bit).
+	bool bSaveCurve14bit;
+
 	// The instrument file list.
 	QStringList instrumentFiles;
 
@@ -255,6 +261,15 @@ public:
 	QStringList audioMeterColors;
 	QStringList midiMeterColors;
 
+	// Transport view options.
+	bool bSyncViewHold;
+
+	// Global persistent user preference options.
+	bool bUseNativeDialogs;
+
+	// Run-time special non-persistent options.
+	bool bDontUseNativeDialogs;
+
 	// Widget geometry persistence helper prototypes.
 	void saveWidgetGeometry(QWidget *pWidget, bool bVisible = false);
 	void loadWidgetGeometry(QWidget *pWidget, bool bVisible = false);
