@@ -1,7 +1,7 @@
 // qtractorPluginForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -87,13 +87,6 @@ qtractorPluginForm::qtractorPluginForm (
 	m_ui.PresetComboBox->setCompleter(NULL);
 
 	// Have some effective feedback when toggling on/off...
-	QIcon iconParams;
-	iconParams.addPixmap(
-		QPixmap(":/images/formParamsOff.png"), QIcon::Active, QIcon::Off);
-	iconParams.addPixmap(
-		QPixmap(":/images/formParamsOn.png"), QIcon::Active, QIcon::On);
-	m_ui.ParamsToolButton->setIcon(iconParams);
-
 	QIcon iconActivate;
 	iconActivate.addPixmap(
 		QPixmap(":/images/itemLedOff.png"), QIcon::Active, QIcon::Off);
@@ -120,9 +113,6 @@ qtractorPluginForm::qtractorPluginForm (
 	QObject::connect(m_ui.DeletePresetToolButton,
 		SIGNAL(clicked()),
 		SLOT(deletePresetSlot()));
-	QObject::connect(m_ui.ParamsToolButton,
-		SIGNAL(toggled(bool)),
-		SLOT(paramsSlot(bool)));
 	QObject::connect(m_ui.EditToolButton,
 		SIGNAL(toggled(bool)),
 		SLOT(editSlot(bool)));
@@ -207,32 +197,23 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	}
 
 	// Maybe we need a tabbed widget...
-	QTabWidget  *pTabWidget = NULL;
-	QVBoxLayout *pVBoxLayout = NULL;
-
-	if (iPages > 1) {
-		pTabWidget  = new QTabWidget();
-		pVBoxLayout = new QVBoxLayout();
-		pVBoxLayout->setMargin(0);
-		pVBoxLayout->setSpacing(4);
-	}
-
-	QGridLayout *pGridLayout = new QGridLayout();
-	pGridLayout->setMargin(8);
-	pGridLayout->setSpacing(4);
+	QTabWidget  *pTabWidget  = NULL;
+	QGridLayout *pGridLayout = NULL;
+	QWidget     *pPageWidget = NULL;
 
 	int iPage = 0;
 	const QString sPage = tr("Page %1");
-	QWidget *pPageWidget = NULL;
-	if (pTabWidget) {	
+	if (iParams > 0) {
+		pTabWidget  = m_ui.TabWidget;
+		pGridLayout = new QGridLayout();
+		pGridLayout->setMargin(8);
+		pGridLayout->setSpacing(4);
 		pPageWidget = new QWidget();
 		pPageWidget->setLayout(pGridLayout);
-		pTabWidget->addTab(pPageWidget, sPage.arg(++iPage));
+		pTabWidget->insertTab(iPage, pPageWidget, sPage.arg(iPage + 1));
+		++iPage;
 	}
 
-	// Plugin might not have its own editor...
-	pGridLayout->setHorizontalSpacing(16);
-
 	// FIXME: Couldn't stand more than a hundred widgets?
 	// or do we have one dedicated editor GUI?
 	int iRow = 0;
@@ -261,19 +242,13 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 					pGridLayout->setSpacing(4);
 					pPageWidget = new QWidget();
 					pPageWidget->setLayout(pGridLayout);
-					pTabWidget->addTab(pPageWidget, sPage.arg(++iPage));
+					pTabWidget->insertTab(iPage, pPageWidget, sPage.arg(iPage + 1));
+					++iPage;
 				}
 			}
 		}
 	}
 
-	if (pVBoxLayout && pTabWidget) {
-		pVBoxLayout->addWidget(pTabWidget);
-		m_ui.ParamsGridWidget->setLayout(pVBoxLayout);
-	} else {
-		m_ui.ParamsGridWidget->setLayout(pGridLayout);
-	}
-
 	// Show editor button if available?
 	const bool bEditor = pType->isEditor();
 	m_ui.EditToolButton->setVisible(bEditor);
@@ -298,12 +273,28 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	// maybe redundant but necessary...
 	m_pPlugin->updateEditorTitle();
 
+	// About page...
+	m_ui.NameTextLabel->setText(pType->name());
+	m_ui.TypeHintTextLabel->setText(
+		qtractorPluginType::textFromHint(pType->typeHint()));
+
+	QString sAboutText = pType->aboutText();
+	sAboutText += '\n';
+	sAboutText += '\n';
+	sAboutText += tr("%1 [%2], %3 instance(s), %4 channel(s).")
+		.arg(pType->filename())
+		.arg(pType->index())
+		.arg(m_pPlugin->instances())
+		.arg(m_pPlugin->channels());
+
+	m_ui.AboutTextLabel->setText(sAboutText);
+
 	// This should trigger paramsSlot(!bEditor)
 	// and adjust the size of the params dialog...
-	m_ui.ParamsToolButton->setVisible(iParams > 0);
-	m_ui.ParamsToolButton->setChecked(iParams > 0);
 	m_ui.DirectAccessParamPushButton->setVisible(iParams > 0);
-	paramsSlot(iParams > 0);
+
+	// Always first tab/page selected...
+	m_ui.TabWidget->setCurrentIndex(0);
 
 	// Clear any initial param update.
 	qtractorSubject::resetQueue();
@@ -534,10 +525,13 @@ void qtractorPluginForm::openPresetSlot (void)
 	const QString  sExt("qtx");
 	const QString& sTitle  = tr("Open Preset") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Preset files (*.%1)").arg(sExt); 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to save...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sFilename = QFileDialog::getOpenFileName(this,
-		sTitle, pOptions->sPresetDir, sFilter);
+		sTitle, pOptions->sPresetDir, sFilter, NULL, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(this,
@@ -551,6 +545,8 @@ void qtractorPluginForm::openPresetSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sPresetDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -610,10 +606,13 @@ void qtractorPluginForm::savePresetSlot (void)
 			if (!fi.exists()) {
 				const QString& sTitle  = tr("Save Preset") + " - " QTRACTOR_TITLE;
 				const QString& sFilter = tr("Preset files (*.%1)").arg(sExt);
-			#if 0//QT_VERSION < 0x040400
+			#if 1//QT_VERSION < 0x040400
 				// Ask for the filename to save...
+				QFileDialog::Options options = 0;
+				if (pOptions->bDontUseNativeDialogs)
+					options |= QFileDialog::DontUseNativeDialog;
 				sFilename = QFileDialog::getSaveFileName(this,
-					sTitle, sFilename, sFilter);
+					sTitle, sFilename, sFilter, NULL, options);
 			#else
 				// Construct save-file dialog...
 				QFileDialog fileDialog(this,
@@ -627,6 +626,8 @@ void qtractorPluginForm::savePresetSlot (void)
 				urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 				urls.append(QUrl::fromLocalFile(pOptions->sPresetDir));
 				fileDialog.setSidebarUrls(urls);
+				if (pOptions->bDontUseNativeDialogs)
+					fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 				// Show dialog...
 				if (fileDialog.exec())
 					sFilename = fileDialog.selectedFiles().first();
@@ -702,32 +703,6 @@ void qtractorPluginForm::deletePresetSlot (void)
 }
 
 
-// Params slot.
-void qtractorPluginForm::paramsSlot ( bool bOn )
-{
-	if (m_pPlugin == NULL)
-		return;
-
-	if (m_iUpdate > 0)
-		return;
-
-	++m_iUpdate;
-
-	m_ui.ParamsGridWidget->setVisible(bOn);
-	if (bOn)
-		m_ui.ParamsGridWidget->show();
-	else
-		m_ui.ParamsGridWidget->hide();
-
-	// Shake it a little bit first, but
-	// make it as tight as possible...
-	resize(width() + 1, height() + 1);
-	adjustSize();
-
-	--m_iUpdate;
-}
-
-
 // Editor slot.
 void qtractorPluginForm::editSlot ( bool bOn )
 {
