@@ -1,7 +1,7 @@
 // qtractorTrackView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -242,6 +242,12 @@ public:
 	void setCurveEdit(bool bCurveEdit);
 	bool isCurveEdit() const;
 
+	// Temporary sync-view/follow-playhead hold state.
+	void setSyncViewHoldOn(bool bOn);
+
+	void setSyncViewHold(bool bSyncViewHold);
+	bool isSyncViewHold() const;
+
 protected:
 
 	// Resize event handler.
@@ -321,6 +327,9 @@ protected:
 	void showClipSelect() const;
 	void hideClipSelect() const;
 
+	// Update whole automation/curve selection.
+	void updateCurveSelect();
+
 	// Show selection tooltip...
 	void showToolTip(const QRect& rect, int dx) const;
 
@@ -536,6 +545,10 @@ private:
 	int m_iDragCurveX;
 
 	qtractorCurveEditCommand *m_pCurveEditCommand;
+
+	// Temporary sync-view/follow-playhead hold state.
+	bool m_bSyncViewHold;
+	int  m_iSyncViewHold;
 };
 
 
