@@ -1,7 +1,7 @@
 // qtractorTracks.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1160,10 +1160,14 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	const QString& sExt = qtractorAudioFileFactory::defaultExt();
 	const QString& sTitle  = tr("Merge/Export Audio Clip") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("Audio files (*.%1)").arg(sExt); 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to save...
+	QFileDialog::Options options = 0;
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	QString sFilename = QFileDialog::getSaveFileName(this, sTitle,
-		pSession->createFilePath(pTrack->trackName(), 0, sExt), sFilter);
+		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(this, sTitle,
@@ -1179,6 +1183,8 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sAudioDir));
 		fileDialog.setSidebarUrls(urls);
+		if (pOptions->bDontUseNativeDialogs)
+			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
 	// Show dialog...
 	if (!fileDialog.exec())
@@ -1299,20 +1305,19 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 			const unsigned long iClipStart = pClip->clipStart();
 			const unsigned long iClipEnd   = iClipStart + pClip->clipLength();;
 			if (iFrameStart < iClipStart && iFrameEnd > iClipStart) {
-				unsigned long iOffset = iFrameEnd - iClipStart;
-				while (!pBuff->inSync(iClipStart - iFrameStart, iOffset))
+				const unsigned long iOffset = iFrameEnd - iClipStart;
+				while (!pBuff->inSync(0, 0))
 					pBuff->syncExport();
 				pBuff->readMix(ppFrames, iOffset,
-					iChannels, iClipStart - iFrameStart,
-					pClip->gain(iOffset));
+					iChannels, iClipStart - iFrameStart, pClip->gain(iOffset));
 			}
 			else
 			if (iFrameStart >= iClipStart && iFrameStart < iClipEnd) {
-				const unsigned long iOffset = iFrameEnd - iClipStart;
-				while (!pBuff->inSync(iFrameStart - iClipStart, iOffset))
+				const unsigned long iFrame = iFrameStart - iClipStart;
+				while (!pBuff->inSync(iFrame, iFrame))
 					pBuff->syncExport();
-				pBuff->readMix(ppFrames, iFrameEnd - iFrameStart,
-					iChannels, 0, pClip->gain(iOffset));
+				pBuff->readMix(ppFrames, iBufferSize,
+					iChannels, 0, pClip->gain(iFrameEnd - iClipStart));
 			}
 		}
 		// Actually write to merge audio file;
@@ -1347,7 +1352,7 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 
 	// Stop logging...
 	if (pMainForm) {
-		pMainForm->addAudioFile(sFilename, true);
+		pMainForm->addAudioFile(sFilename);
 		pMainForm->appendMessages(
 			tr("Audio clip merge/export: \"%1\" complete.")
 			.arg(sFilename));
@@ -1421,10 +1426,14 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 	const QString  sExt("mid");
 	const QString& sTitle  = tr("Merge/Export MIDI Clip") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt); 
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to save...
+	QFileDialog::Options options = 0;
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	QString sFilename = QFileDialog::getSaveFileName(this, sTitle,
-		pSession->createFilePath(pTrack->trackName(), 0, sExt), sFilter);
+		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(this, sTitle,
@@ -1440,6 +1449,8 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sMidiDir));
 		fileDialog.setSidebarUrls(urls);
+		if (pOptions->bDontUseNativeDialogs)
+			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
 	// Show dialog...
 	if (!fileDialog.exec())
@@ -1592,7 +1603,7 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 
 	// Stop logging...
 	if (pMainForm) {
-		pMainForm->addMidiFile(sFilename, true);
+		pMainForm->addMidiFile(sFilename);
 		pMainForm->appendMessages(
 			tr("MIDI clip merge/export: \"%1\" complete.")
 			.arg(sFilename));
@@ -2410,7 +2421,7 @@ bool qtractorTracks::addTrack (void)
 	const int iTrack = pSession->tracks().count() + 1;
 	const QColor& color = qtractorTrack::trackColor(iTrack);
 	qtractorTrack *pTrack = new qtractorTrack(pSession);
-	pTrack->setTrackName(QString("Track %1").arg(iTrack));
+	pTrack->setTrackName(tr("Track %1").arg(iTrack));
 	pTrack->setMidiChannel(pSession->midiTag() % 16);
 	pTrack->setBackground(color);
 	pTrack->setForeground(color.darker());
