@@ -1,7 +1,7 @@
 // qtractorVstPlugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -219,7 +219,7 @@ public:
 			m_pVstPlugin = NULL;
 		}
 
-		int iIndex = g_vstEditors.indexOf(this);
+		const int iIndex = g_vstEditors.indexOf(this);
 		if (iIndex >= 0)
 			g_vstEditors.removeAt(iIndex);
 	}
@@ -275,6 +275,9 @@ protected:
 			(m_pVstPlugin->form())->toggleEditor(false);
 
 		QWidget::closeEvent(pCloseEvent);
+
+		if (m_pVstPlugin)
+			m_pVstPlugin->closeEditor();
 	}
 
 	void moveEvent(QMoveEvent *pMoveEvent)
@@ -407,8 +410,9 @@ bool qtractorVstPluginType::open (void)
 #endif
 
 	// Retrieve plugin type names.
-	char szName[256]; ::memset(szName, 0, sizeof(szName));
-	if (vst_dispatch(effGetEffectName, 0, 0, (void *) szName, 0.0f))
+	char szName[32]; szName[0] = (char) 0;
+	vst_dispatch(effGetEffectName, 0, 0, (void *) szName, 0.0f);
+	if (szName[0])
 		m_sName = szName;
 	else
 		m_sName = QFileInfo(filename()).baseName();
@@ -417,7 +421,7 @@ bool qtractorVstPluginType::open (void)
 
 	// Retrieve plugin unique identifier.
 #ifdef CONFIG_VESTIGE_OLD
-	m_iUniqueID = qHash(filename());
+	m_iUniqueID = qHash(m_sLabel);
 #else
 	m_iUniqueID = pVstEffect->uniqueID;
 #endif
@@ -536,6 +540,40 @@ bool qtractorVstPluginType::vst_canDo ( const char *pszCanDo ) const
 }
 
 
+// Instance cached-deferred accesors.
+const QString& qtractorVstPluginType::aboutText (void)
+{
+	if (m_sAboutText.isEmpty()) {
+		char szTemp[64];
+		szTemp[0] = (char) 0;
+		vst_dispatch(effGetProductString, 0, 0, (void *) szTemp, 0.0f);
+		if (szTemp[0]) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+			m_sAboutText += QObject::tr("Product: ");
+			m_sAboutText += szTemp;
+		}
+		szTemp[0] = (char) 0;
+		vst_dispatch(effGetVendorString, 0, 0, (void *) szTemp, 0.0f);
+		if (szTemp[0]) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+			m_sAboutText += QObject::tr("Vendor: ");
+			m_sAboutText += szTemp;
+		}
+		const int iVersion = vst_dispatch(effGetVendorVersion, 0, 0, NULL, 0.0f);
+		if (iVersion) {
+			if (!m_sAboutText.isEmpty())
+				m_sAboutText += '\n';
+			m_sAboutText += QObject::tr("Version: ");
+			m_sAboutText += QString::number(iVersion);
+		}
+	}
+
+	return m_sAboutText;
+}
+
+
 //----------------------------------------------------------------------------
 // qtractorVstPlugin -- VST plugin instance.
 //
@@ -989,7 +1027,7 @@ void qtractorVstPlugin::idleEditor (void)
 	if (m_pEditorWidget == NULL)
 		return;
 
-#ifdef CONFIG_DEBUG
+#ifdef CONFIG_DEBUG_0
 	qDebug("qtractorVstPlugin[%p]::idleEditor()", this);
 #endif
 
@@ -1302,16 +1340,18 @@ static VstIntPtr qtractorVstPlugin_openFileSelector (
 				.arg(pvfs->fileTypes[i].name).arg(pvfs->fileTypes[i].dosType));
 		}
         filters.append(QObject::tr("All files (*.*)"));
-		QString sFilter = filters.join(";;");
-		QString sDirectory = pvfs->initialPath;
-		QString sTitle = QString("%1 - %2")
+		QWidget *pParentWidget = pVstPlugin->editorWidget();
+		const QString& sTitle = QString("%1 - %2")
 			.arg(pvfs->title).arg((pVstPlugin->type())->name());
+		const QString& sDirectory = pvfs->initialPath;
+		const QString& sFilter = filters.join(";;");
+		const QFileDialog::Options options = QFileDialog::DontUseNativeDialog;
 		if (pvfs->command == kVstFileLoad) {
 			sFilename = QFileDialog::getOpenFileName(
-				pVstPlugin->editorWidget(), sTitle, sDirectory, sFilter);
+				pParentWidget, sTitle, sDirectory, sFilter, NULL, options);
 		} else {
 			sFilename = QFileDialog::getSaveFileName(
-				pVstPlugin->editorWidget(), sTitle, sDirectory, sFilter);
+				pParentWidget, sTitle, sDirectory, sFilter, NULL, options);
 		}
 		if (!sFilename.isEmpty()) {
 			if (pvfs->returnPath == NULL) {
@@ -1324,11 +1364,13 @@ static VstIntPtr qtractorVstPlugin_openFileSelector (
     }
 	else
 	if (pvfs->command == kVstDirectorySelect) {
-		QString sDirectory = pvfs->initialPath;
-		QString sTitle = QString("%1 - %2")
+		QWidget *pParentWidget = pVstPlugin->editorWidget();
+		const QString& sTitle = QString("%1 - %2")
 			.arg(pvfs->title).arg((pVstPlugin->type())->name());
-		sDirectory = QFileDialog::getExistingDirectory(
-			pVstPlugin->editorWidget(), sTitle, sDirectory);
+		const QString& sDirectory
+			= QFileDialog::getExistingDirectory(
+				pParentWidget, sTitle, pvfs->initialPath,
+				QFileDialog::ShowDirsOnly | QFileDialog::DontUseNativeDialog);
 		if (!sDirectory.isEmpty()) {
 			if (pvfs->returnPath == NULL) {
 				pvfs->returnPath = new char [sDirectory.length() + 1];
