@@ -1,7 +1,7 @@
 // qtractorVstPlugin.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -74,6 +74,9 @@ public:
 	int vst_dispatch(
 		long opcode, long index, long value, void *ptr, float opt) const;
 
+	// Instance cached-deferred accesors.
+	const QString& aboutText();
+
 protected:
 
 	// VST flag inquirer.
